<?php

/**
 * @copyright	Copyright (C) 2013-2014 ProVision.1 - All rights reserved.
 * @license	GNU General Public License version 2 or later
 */

// No direct access
defined('_JEXEC') or die;

// Constants
define('JPATH_PLUGIN_SMARTAPPBANNER', JURI::root().'plugins/system/smartappbanner');
define('JPATH_PLUGIN_SMARTAPPBANNER_ICONS', JURI::root().'images');

/**
 * Mobile Smart App Banner System Plugin
 *
 * @package	Joomla.Plugin
 * @subpackage	System.smartappbanner
 */
class plgSystemSmartAppBanner extends JPlugin 
{

    /**
     * Constructor 
     * 
     * @access      protected
     * @param       object  $subject The object to observe
     * @param       array   $config  An array that holds the plugin configuration
     */
    public function __construct(&$subject, $config) 
    {
        parent::__construct($subject, $config);
        $this->loadLanguage();
    }

    public function onAfterDispatch()
    {
        // Restrict plugin to frontend
        $app = JFactory::getApplication();
        if(!$app->isSite()) 
            return true;
        
        // Handle frontpage exclusive mode
        if ($this->params->get('frontpage-exclusive'))
        {
            $app = JFactory::getApplication();
            $menu = $app->getMenu();
            
            if ($menu->getActive() != $menu->getDefault()) 
                return true;
        }
        
        // Add banners
        $this->addIOSBanner();
        $this->addAndroidBanner();
        $this->addWindowsBanner();
                
        return true;
    }
    
    /**
     * Adds the iOS Smart Banner
     * @return boolean  true on success
     */
    private function addIOSBanner() {
        
        // Abort, if no app id was set in the ios plugin preferences
        $iOSAppID = $this->params->get('ios-app-id');
        if (empty($iOSAppID))
            return false;
                
        // Prepare meta tag data
        $metaTagName = 'apple-itunes-app';
        $metaTagContent = 'app-id='.$iOSAppID;
        
        $iOSAffilData = $this->params->get('ios-affiliate-data');
        if (!empty($iOSAffilData)) 
        {
            $metaTagContent .= ', ';
            $metaTagContent .= 'affiliate-data='.$iOSAffilData;   
        }
        
        $iOSAppArgument = $this->params->get('ios-app-argument');
        if (!empty($iOSAppArgument)) 
        {
            $metaTagContent .= ', ';
            $metaTagContent .= 'app-argument='.$iOSAppArgument; 
        }
        
        $doc = JFactory::getDocument();
        $doc->setMetaData( $metaTagName, $metaTagContent );
        
        return true;
    }
    
    
    /**
     * Adds the Android Smart Banner
     * @return boolean  true on success
     */
    private function addAndroidBanner() {
        
        // Abort, if no app id was set in the android plugin preferences
        $androidAppID = $this->params->get('android-app-id');
        if (empty($androidAppID))
            return false;
        
         // Load jquery framework depending on joomla system
        jimport('cms.version.version');
        $joomVer = new JVersion();
        $doc = JFactory::getDocument();
        
        if($joomVer->isCompatible('3.0')) 
        {
            JHtml::_('jquery.framework');
        } 
        else
        {
            // Detect jquery or jquery easy plugin
            $db = JFactory::getDbo();
            $db->setQuery("SELECT enabled FROM #__extensions WHERE element = 'jqueryeasy'");
            $jqPresent = $db->loadResult();

            if (!$jqPresent ) {
                $header = $doc->getHeadData(); 
                $jqmatch = 'jquery';

                foreach($header['scripts'] as $scriptName => $scriptData) 
                {
                    if(preg_match('/'.$jqmatch.'/i',$scriptName))
                    {
                        $jqPresent = true;
                        break;
                    }
                }
            }
            
            if(!$jqPresent) {
                JError::raiseNotice( 100, JText::_('PLG_SYSTEM_SMARTAPPBANNER_JQUERYEASY_NOT_INSTALLED_ADMIN') );
                return false;
            }
        }
       
        // Add needed javascript and css files
        $doc->addScript(JPATH_PLUGIN_SMARTAPPBANNER.'/js/jquery.smartbanner.js');
        $doc->addStyleSheet(JPATH_PLUGIN_SMARTAPPBANNER.'/css/jquery.smartbanner.css');
        
        // Generate meta tag
        $metaTagName = 'google-play-app';
        $metaTagContent = 'app-id='.$androidAppID;  
        $doc->setMetaData($metaTagName, $metaTagContent);
        
        // Generate script init command with options
        $scriptCommand = 'jQuery.smartbanner({ ';
        $scriptCommand .= 'title: "'.$this->params->get('android-app-title').'"';

        if(strlen($this->params->get('android-app-author')))
            $scriptCommand .= ', author: "'.$this->params->get('android-app-author').'"';     
        if($this->params->get('android-app-icon') != '-1')
            $scriptCommand .= ', icon: "'.JPATH_PLUGIN_SMARTAPPBANNER_ICONS.'/'.$this->params->get('android-app-icon').'"';
        if(strlen($this->params->get('android-app-price')))
            $scriptCommand .= ', price: "'.$this->params->get('android-app-price').'"';       
        if(strlen($this->params->get('android-playstore-text')))
            $scriptCommand .= ', inGooglePlay: "'.$this->params->get('android-playstore-text').'"'; 
        if(strlen($this->params->get('android-button-text')))
            $scriptCommand .= ', button: "'.$this->params->get('android-button-text').'"';      
        if($this->params->get('android-scale-mode'))
            $scriptCommand .= ', scale: "'.$this->params->get('android-scale-mode').'"';      
        if(strlen($this->params->get('android-animation-speedin')))
            $scriptCommand .= ', speedIn: '.$this->params->get('android-animation-speedin');    
        if(strlen($this->params->get('android-animation-speedout')))
            $scriptCommand .= ', speedOut: '.$this->params->get('android-animation-speedout'); 
        if(strlen($this->params->get('android-days-hidden')))
            $scriptCommand .= ', daysHidden: '.$this->params->get('android-days-hidden'); 
        if(strlen($this->params->get('android-days-reminder')))
            $scriptCommand .= ', daysReminder: '.$this->params->get('android-days-reminder'); 
        if($this->params->get('android-test-mode') != '0')
            $scriptCommand .= ', force: "'.$this->params->get('android-test-mode').'"'; 
        
        $scriptCommand .= ' });';
        
        $scriptOnPageLoad = 'jQuery(document).ready(function() { ';
        $scriptOnPageLoad .= $scriptCommand;
        $scriptOnPageLoad .= ' });';
        
        $doc->addScriptDeclaration($scriptOnPageLoad);
    
        return true;
    }
    
    
    /**
     * Adds the Windows Smart Banner
     * @return boolean  true on success
     */
    private function addWindowsBanner() {
        
        // Abort, if no app id was set in the windows plugin preferences
        $winAppID = $this->params->get('windows-app-id');
        if (empty($winAppID))
            return false;
        
        // Get the document data
        $doc = JFactory::getDocument();
        
        // Generate meta tags
        $metaTagName = 'msApplication-ID';
        $metaTagContent = $winAppID;  
        $doc->setMetaData($metaTagName, $metaTagContent);
        
        $winPackName = $this->params->get('windows-package-name');
        if (!empty($winPackName)) 
        {
            $metaTagName = 'msApplication-PackageFamilyName';
            $metaTagContent = $winPackName;  
            $doc->setMetaData($metaTagName, $metaTagContent);
        }
        
        $winAppArgs = $this->params->get('windows-app-arguments');
        if (!empty($winAppArgs)) 
        {
            $metaTagName = 'msApplication-Arguments';
            $metaTagContent = $winAppArgs;  
            $doc->setMetaData($metaTagName, $metaTagContent);
        }
        
        $winMinVer = $this->params->get('windows-required-minversion');
        if (!empty($winMinVer)) 
        {
            $metaTagName = 'msApplication-MinVersion';
            $metaTagContent = $winMinVer;  
            $doc->setMetaData($metaTagName, $metaTagContent);
        }
        
        $winOptOut = $this->params->get('windows-optout');
        if ($winOptOut != 'disabled') 
        {
            $metaTagName = 'msApplication-OptOut';
            $metaTagContent = $winOptOut;  
            $doc->setMetaData($metaTagName, $metaTagContent);
        }
        
        return true;
    }

}
